@@ -6,18 +6,6 @@ from surveymonkey.exceptions import UnknownError, BadRequestError, Authorization
     ResourceNotFoundError, ResourceConflictError, RequestEntityTooLargeError, RateLimitReachedError, \
     InternalServerError, UserSoftDeletedError, UserDeletedError
 
-# BASE_URL = 'https://www.zohoapis.com/crm/v2/'
-# ZOHOCRM_AUTHORIZE_URL = 'https://accounts.zoho.com/oauth/v2/auth'
-# ZOHOCRM_REQUEST_TOKEN_URL = 'https://accounts.zoho.com/oauth/v2/token'
-# ZOHOCRM_REFRESH_TOKEN_URL = "https://accounts.zoho.com/oauth/v2/token"
-# READ_MODULE_LIST = ['leads', 'accounts', 'contacts', 'deals', 'campaigns', 'tasks', 'cases', 'events', 'calls',
-#                     'solutions', 'products', 'vendors', 'pricebooks', 'quotes', 'salesorders', 'purchaseorders',
-#                     'invoices', 'custom', 'notes', 'approvals', 'dashboards', 'search', 'activities']
-# module purchaseorders, 'invoices', salesorders and quotes are temporarily disable for writing this
-# due to the complexity of the module
-# WRITE_MODULE_LIST = ['leads', 'accounts', 'contacts', 'deals', 'campaigns', 'tasks', 'cases', 'events', 'calls',
-#                      'solutions', 'products', 'vendors', 'pricebooks', 'purchaseorders', 'custom', 'notes']
-
 '''
 Token expiration and revocation
 Our access tokens don’t currently expire but may in the future. We’ll warn all developers before making changes.
@@ -35,14 +23,12 @@ ACCESS_TOKEN_URL = "/oauth/token"
 
 class Client(object):
 
-    def __init__(self, client_id, client_secret, redirect_uri, scope, access_type):
+    def __init__(self, client_id=None, client_secret=None, redirect_uri=None, access_token=None):
         self.code = None
-        self.scope = scope
-        self.access_type = access_type
         self.client_id = client_id
         self.redirect_uri = redirect_uri
         self.client_secret = client_secret
-        self._access_token = None
+        self._access_token = access_token
 
     # Authorization
     def get_authorization_url(self):
@@ -62,8 +48,12 @@ class Client(object):
         """
         params = {'code': code, 'client_id': self.client_id, 'client_secret': self.client_secret,
                   'redirect_uri': self.redirect_uri, 'grant_type': 'authorization_code'}
-        url = BASE_URL + ACCESS_TOKEN_URL + '?' + urlencode(params)
-        return self._post(url, data=params)
+        url = BASE_URL + ACCESS_TOKEN_URL
+        response = requests.post(url, data=params)
+        if response.status_code == 200 and 'access_token' in response.text:
+            return response.text
+        else:
+            return False
 
     def refresh_token(self):
         """
@@ -726,7 +716,7 @@ class Client(object):
         else:
             r = response.text
         if "error" in r:
-            self.get_error(r)
+            self.get_error(dict(r))
         if "error" not in r and status_code not in [200, 201, 204]:
             raise UnknownError()
         if status_code in (200, 201):
@@ -736,10 +726,10 @@ class Client(object):
 
     def get_error(self, error):
         """
-        
-        :return: 
+
+        :return:
         """
-        error_code = error['error']['id']
+        error_code = error['error']
         error_message = error['message']
         if error_code == "1000":
             raise BadRequestError(error_message)
